---
name: '✨ Enhancement Request'
about: Suggest an enhancement to external-dns
title: ''
labels: '✨ enhancement'
assignees: ''
---

<!-- Please only use this template for submitting enhancement requests.  -->

**What would you like to be added**:

**Why is this needed**:
